/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" 
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.apache.geronimo.console.filter;

import java.io.IOException;
import java.io.OutputStream;

import javax.servlet.ServletOutputStream;

/**
 * Implementation of a ServletOutputStream, so we can manipulate the stream
 * before committing it in a ServletResponse.
 *
 * @version $Rev: 758252 $ $Date: 2009-03-25 09:39:24 -0400 (Wed, 25 Mar 2009) $
 */
public final class ResponseOutputStream extends ServletOutputStream {

    private OutputStream stream = null;

    /**
     * Default constructor for our wrappered ServletResponse stream.
     * @param os
     */
    public ResponseOutputStream(OutputStream os) {
        stream = os;
    }

    //----- Required method overrides for java.io.OutputStream -----

    /* (non-Javadoc)
     * @see java.io.OutputStream#close()
     */
    @Override
    public void close() throws IOException {
        stream.close();
    }

    /* (non-Javadoc)
     * @see java.io.OutputStream#flush()
     */
    @Override
    public void flush() throws IOException {
        stream.flush();
    }

    /* (non-Javadoc)
     * @see java.io.OutputStream#write(byte[])
     */
    @Override
    public void write(byte[] b) throws IOException {
        stream.write(b);
    }

    /* (non-Javadoc)
     * @see java.io.OutputStream#write(int)
     */
    @Override
    public void write(int b) throws IOException {
        stream.write(b);
    }
}
